# eric7.QScintilla.DocstringGenerator

Package containing the documentation string generator tool.

### Modules

BaseDocstringGenerator | Module implementing a docstring generator base class.
EricdocGenerator | Module implementing the docstring generator for the 'ericdoc' style.
GoogledocGenerator | Module implementing the docstring generator for the 'sphinxdoc' style.
NumpydocGenerator | Module implementing the docstring generator for the 'numpydoc' style.
PyDocstringGenerator | Module implementing a docstring generator for Python.
SphinxdocGenerator | Module implementing the docstring generator for the 'sphinxdoc' style.
DocstringGenerator | Package containing the documentation string generator tool.